:orphan:

`plasmapy.particles.ionization_state_collection`
================================================

.. currentmodule:: plasmapy.particles.ionization_state_collection

.. automodapi::  plasmapy.particles.ionization_state_collection
